#
# spec file for package amanda
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define amanda_group amanda
%define upstreamver tag-community-%{version}
Name:           amanda
Version:        3.5.4
Release:        4.3
Summary:        Network Disk Archiver
License:        GPL-3.0-or-later
URL:            http://www.amanda.org/
Source:         https://github.com/zmanda/amanda/archive/%{upstreamver}/%{name}-%{version}.tar.gz
#amanda-SUSE.tar.bz2 contains init scripts, config examples
Source1:        amanda-SUSE.tar.bz2
Source2:        amanda-howto-collection.pdf.tar.bz2
Patch1:         amanda-2.6.1p1-shellbang.patch
Patch2:         amanda-2.6.1p1-return_val.patch
Patch3:         amanda-2.6.1p1-avoid-perl-provides.patch
Patch4:         amanda-3.3.2-returnvalues.patch
Patch6:         amanda-3.5-no_return_in_nonvoid_fnc.patch
Patch7:         amanda-libnsl.patch
Patch8:         amanda-fix-proto.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  cups-client
BuildRequires:  dump
BuildRequires:  flex
BuildRequires:  gawk
BuildRequires:  gcc
BuildRequires:  glib2-devel
BuildRequires:  gnuplot
BuildRequires:  krb5-devel
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  mailx
BuildRequires:  mtx
BuildRequires:  openssh
BuildRequires:  openssl-devel
BuildRequires:  perl-base
BuildRequires:  pkgconfig
BuildRequires:  popt-devel
BuildRequires:  procps
BuildRequires:  readline-devel
BuildRequires:  rpcgen
BuildRequires:  samba-client
BuildRequires:  sendmail
BuildRequires:  swig
BuildRequires:  perl(ExtUtils::Embed)
BuildRequires:  perl(Test::Simple)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(smbclient)
Requires:       %{_bindir}/smbclient
Requires:       dump
Requires:       grep
Requires:       perl = %{perl_version}
Requires:       tar
Requires(post): permissions
Requires(pre):  shadow
Provides:       group(amanda)
Provides:       user(amanda)

%description
AMANDA, the Advanced Maryland Automatic Network Disk Archiver, is a backup
solution that allows the IT administrator to set up a single master backup
server to back up multiple hosts over network to tape drives/changers or
disks or optical media. Amanda uses native utilities and formats (e.g. dump
and/or GNU tar) and can back up a large number of servers and workstations
running multiple versions of Linux or Unix.

%prep
%setup -q -n %{name}-%{upstreamver} -a 1 -a 2
%patch -P 1
%patch -P 2
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 6 -p1
%patch -P 7 -p1
%patch -P 8 -p1

%build
./autogen

export CFLAGS="%{optflags} -fno-strict-aliasing -fPIC -fPIE"
export CXXFLAGS="%{optflags} -fno-strict-aliasing -fPIC -fPIE"
export LDFLAGS="-pie"
%configure --with-bsdtcp-security \
           --with-bsdudp-security \
           --with-ssh-security \
           --with-rsh-security \
           --with-krb5-security \
           --with-index-server=localhost \
           --with-gnutar-listdir=%{_localstatedir}/lib/amanda/gnutar-lists \
           --with-smbclient=%{_bindir}/smbclient \
           --with-amperldir=%{perl_vendorlib} \
           --with-user=amanda \
           --with-group=%{amanda_group} \
           --with-gnutar=/bin/tar \
           --disable-libtool \
           --with-amandahosts \
           --disable-installperms
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}/
install -d %{buildroot}/%{_sysconfdir}/amanda \
           %{buildroot}%{_localstatedir}/lib/amanda/index \
           %{buildroot}%{_localstatedir}/lib/amanda/gnutar-lists \
           %{buildroot}%{_localstatedir}/lib/amanda/disklist \
           %{buildroot}%{_localstatedir}/lib/amanda/DailySet1 \
           %{buildroot}%{_localstatedir}/lib/amanda/lbl-templ \
           %{buildroot}/%{_docdir}/%{name} \
           %{buildroot}/%{_sysconfdir}/xinetd.d
install NEWS README.md README.SUSE example/{amanda.conf,chg-multi.conf,disklist} %{buildroot}/%{_docdir}/%{name}
install -m 644 %{buildroot}%{_sysconfdir}/amanda/amanda-security.conf %{buildroot}%{_sysconfdir}/amanda-security.conf
chmod 644 %{buildroot}/%{_docdir}/%{name}/* %{buildroot}/%{_mandir}/*/*
cp -a SUSE/* %{buildroot}

# pdf doc
cp amanda-howto-collection.pdf %{buildroot}/%{_docdir}/%{name}/

# label templates
cp -a example/*.ps %{buildroot}%{_localstatedir}/lib/amanda/lbl-templ

# contain docs, examples which are already included
rm -rf %{buildroot}%{_datadir}/amanda

# bnc#412636
touch %{buildroot}/%{_libexecdir}/amanda/exclude.gtar

# delete all static linking remnats
find %{buildroot} \( -name "*.a" -o -name "*.la" \) -delete

# create a list of binaries to be checked externally
cat << EOF > %{buildroot}%{_libexecdir}/amanda/suidlist
%{_libexecdir}/amanda/ambind
%{_libexecdir}/amanda/application/ambsdtar
%{_libexecdir}/amanda/application/amgtar
%{_libexecdir}/amanda/application/amstar
%{_libexecdir}/amanda/calcsize
%{_libexecdir}/amanda/killpgrp
%{_libexecdir}/amanda/rundump
%{_libexecdir}/amanda/runtar
EOF

# create a symlink for amoldrecover manpage
ln -s amrecover.8.gz %{buildroot}%{_mandir}/man8/amoldrecover.8

%pre
# since 11.2 we use group "tape" instead of "disk" for tape devices /dev/nst*,
# so we must check group for "amanda" user
# create primary group for amanda user
%{_sbindir}/groupadd -r amanda 2>/dev/null || :
# if user already exists and has effective group "disk", we have to change this group
# to "amanda" group and also add supplementary "tape" group see bnc#523006
# else - move amanda to group amanda unconditionally (ignore failures if amanda doesn't exist)
%{_bindir}/id -n -g amanda 2>&1 | grep "disk" >/dev/null \
    && %{_sbindir}/usermod -g amanda -G tape amanda \
    || %{_sbindir}/usermod -g amanda amanda 2>&1 \
    || :
# this is ugly but just simple add user with "tape" and "amanda" groups regardless of existing user
%{_sbindir}/useradd -r -o -g amanda -G tape -u 37 -s /bin/bash \
    -c "Amanda admin" -d %{_localstatedir}/lib/amanda amanda >/dev/null 2>&1 || :

%post
%if 0%{?set_permissions:1}
%set_permissions %{_libexecdir}/amanda/ambind %{_libexecdir}/amanda/application/ambsdtar %{_libexecdir}/amanda/application/amgtar %{_libexecdir}/amanda/application/amstar %{_libexecdir}/amanda/calcsize %{_libexecdir}/amanda/killpgrp %{_libexecdir}/amanda/rundump %{_libexecdir}/amanda/runtar
%else
%run_permissions
%endif

%verifyscript
%verify_permissions -f %{_libexecdir}/amanda/suidlist

%files
%doc amanda-howto-collection.pdf ChangeLog NEWS AUTHORS COPYRIGHT README.md ReleaseNotes README.SUSE
%doc %attr(755,root,root) %dir %{_docdir}/%{name}
%{_docdir}/%{name}/*
%{_mandir}/man*/*
%config %{_libexecdir}/amanda/exclude.gtar
%attr(755,root,root) %dir %{_libexecdir}/amanda
%attr(664,amanda,%{amanda_group}) %config(noreplace) %{_sysconfdir}/dumpdates
%attr(664,amanda,%{amanda_group}) %config(noreplace) %{_sysconfdir}/amandates
%attr(755,amanda,%{amanda_group}) %dir %{_sysconfdir}/amanda
%attr(755,amanda,%{amanda_group}) %dir %{_sysconfdir}/amanda/example
%attr(755,amanda,%{amanda_group}) %dir %{_localstatedir}/lib/amanda/
%attr(755,amanda,%{amanda_group}) %dir %{_localstatedir}/lib/amanda/disklist
%attr(755,amanda,%{amanda_group}) %dir %{_localstatedir}/lib/amanda/gnutar-lists/
%attr(755,amanda,%{amanda_group}) %dir %{_localstatedir}/lib/amanda/index/
%attr(755,amanda,%{amanda_group}) %dir %{_localstatedir}/lib/amanda/DailySet1
%attr(755,amanda,%{amanda_group}) %dir %{_localstatedir}/lib/amanda/lbl-templ
%attr(644,amanda,%{amanda_group}) %{_localstatedir}/lib/amanda/lbl-templ/*
%config %attr(644,amanda,%{amanda_group}) %{_localstatedir}/lib/amanda/.bashrc
%config %attr(644,amanda,%{amanda_group}) %{_localstatedir}/lib/amanda/.profile
# bnc#412636 file permissions of .amandahosts should be 600
%config %attr(600,amanda,%{amanda_group}) %{_localstatedir}/lib/amanda/.amandahosts
%config %attr(644,amanda,%{amanda_group}) %{_sysconfdir}/amanda/example/amanda.conf
# amanda-security.conf must be installed at %%{_sysconfdir} and only root must be able to write it
# an example file should be installed at %%{_sysconfdir}/amanda/
%config(noreplace) %attr(644, root, root) %{_sysconfdir}/amanda-security.conf
%{_sysconfdir}/amanda/amanda-security.conf
%config %attr(644,amanda,%{amanda_group}) %{_sysconfdir}/amanda/example/disklist
%dir %{_sysconfdir}/xinetd.d
%config(noreplace) %{_sysconfdir}/xinetd.d/*
# perl scripts
%dir %{perl_vendorlib}/Amanda/
%dir %{perl_vendorlib}/Amanda/Application
%dir %{perl_vendorlib}/Amanda/Changer
%dir %{perl_vendorlib}/Amanda/Config
%dir %{perl_vendorlib}/Amanda/Curinfo
%dir %{perl_vendorlib}/Amanda/DB
%dir %{perl_vendorlib}/Amanda/FetchDump
%dir %{perl_vendorlib}/Amanda/Chunker
%dir %{perl_vendorlib}/Amanda/Interactivity
%dir %{perl_vendorlib}/Amanda/IPC
%dir %{perl_vendorlib}/Amanda/Recovery
%dir %{perl_vendorlib}/Amanda/Report
%dir %{perl_vendorlib}/Amanda/Rest
%dir %{perl_vendorlib}/Amanda/Rest/Storages
%dir %{perl_vendorlib}/Amanda/Service
%dir %{perl_vendorlib}/Amanda/Taper
%dir %{perl_vendorlib}/Amanda/Taper/Scan
%dir %{perl_vendorlib}/auto/Amanda/
%dir %{perl_vendorlib}/auto/Amanda/Application
%dir %{perl_vendorlib}/auto/Amanda/Archive
%dir %{perl_vendorlib}/auto/Amanda/Cmdline
%dir %{perl_vendorlib}/auto/Amanda/Cmdfile
%dir %{perl_vendorlib}/auto/Amanda/Config
%dir %{perl_vendorlib}/auto/Amanda/Debug
%dir %{perl_vendorlib}/auto/Amanda/Device
%dir %{perl_vendorlib}/auto/Amanda/Disklist
%dir %{perl_vendorlib}/auto/Amanda/Feature
%dir %{perl_vendorlib}/auto/Amanda/Header
%dir %{perl_vendorlib}/auto/Amanda/IPC
%dir %{perl_vendorlib}/auto/Amanda/IPC/Binary
%dir %{perl_vendorlib}/auto/Amanda/Logfile
%dir %{perl_vendorlib}/auto/Amanda/MainLoop
%dir %{perl_vendorlib}/auto/Amanda/NDMP
%dir %{perl_vendorlib}/auto/Amanda/Tapelist
%dir %{perl_vendorlib}/auto/Amanda/Tests
%dir %{perl_vendorlib}/auto/Amanda/Util
%dir %{perl_vendorlib}/auto/Amanda/Xfer
%dir %{perl_vendorlib}/auto/Amanda/XferServer
%{perl_vendorlib}/Amanda/*/*/*.pm
%{perl_vendorlib}/Amanda/*/*.pm
%{perl_vendorlib}/Amanda/*.pm
%{perl_vendorlib}/auto/Amanda/*/*.so
%{perl_vendorlib}/auto/Amanda/*/*/*.so
%defattr(755,root,%{amanda_group})
%{_sbindir}/amadmin
%{_sbindir}/ambackup
%{_sbindir}/amreindex
%{_sbindir}/amssl
%{_sbindir}/amanda-rest-server
%{_sbindir}/amcheckdb
%{_sbindir}/amcleanup
%{_sbindir}/amdump
%{_sbindir}/amflush
%{_sbindir}/amgetconf
%{_sbindir}/amlabel
%{_sbindir}/amoverview
%{_sbindir}/amplot
%{_sbindir}/amcheck
%attr(0750,root,%{amanda_group}) %{_sbindir}/amrecover
%{_sbindir}/amreport
%{_sbindir}/amrestore
%{_sbindir}/amrmtape
%{_sbindir}/amstatus
%{_sbindir}/amtape
%{_sbindir}/amtapetype
%{_sbindir}/amtoc
%{_sbindir}/amcrypt-ossl
%{_sbindir}/amcrypt-ossl-asym
%{_sbindir}/amoldrecover
%{_sbindir}/amgpgcrypt
%{_sbindir}/amaespipe
%{_sbindir}/amcrypt
%{_sbindir}/amfetchdump
%{_sbindir}/amaddclient
%{_sbindir}/amarchiver
%{_sbindir}/amcheckdump
%{_sbindir}/amcryptsimple
%{_sbindir}/amdevcheck
%{_sbindir}/amdump_client
%{_sbindir}/amserverconfig
%{_sbindir}/amservice
%{_sbindir}/amvault
%{_sbindir}/activate-devpay
%defattr(644,root,%{amanda_group})
%{_libexecdir}/amanda/suidlist
%{_libexecdir}/amanda/amcat.awk
%{_libexecdir}/amanda/amplot.awk
%{_libexecdir}/amanda/amplot.g
%{_libexecdir}/amanda/amplot.gp
%defattr(755,root,%{amanda_group})
%{_libexecdir}/amanda/amandad
%{_libexecdir}/amanda/amdumpd
%{_libexecdir}/amanda/amidxtaped
%{_libexecdir}/amanda/amindexd
%{_libexecdir}/amanda/amtrmidx
%{_libexecdir}/amanda/driver
%{_libexecdir}/amanda/amadmin_perl
%{_libexecdir}/amanda/ambackupd
%{_libexecdir}/amanda/rest-server/
%{_libexecdir}/amanda/amcheck-device
%{_sbindir}/amcleanupdisk
%{_libexecdir}/amanda/amlogroll
%{_libexecdir}/amanda/amndmjob
%{_libexecdir}/amanda/amtrmlog
%{_libexecdir}/amanda/patch-system
%{_libexecdir}/amanda/selfcheck
%{_libexecdir}/amanda/sendbackup
%{_libexecdir}/amanda/sendsize
%{_libexecdir}/amanda/taper
%{_libexecdir}/amanda/chunker
%{_libexecdir}/amanda/noop
%{_libexecdir}/amanda/ndmjob
%{_libexecdir}/amanda/amanda-sh-lib.sh
%{_libexecdir}/amanda/teecount
%{_libexecdir}/amanda/restore
%{_libexecdir}/amanda/senddiscover
%{_libexecdir}/amanda/dumper
%{_libexecdir}/amanda/planner
%attr(0755 root root) %dir %{_libexecdir}/amanda/application/
%{_libexecdir}/amanda/application/amlog-script
%{_libexecdir}/amanda/application/ampgsql
%{_libexecdir}/amanda/application/amrandom
%{_libexecdir}/amanda/application/amraw
%{_libexecdir}/amanda/application/amsamba
%{_libexecdir}/amanda/application/amsuntar
%{_libexecdir}/amanda/application/amzfs-sendrecv
%{_libexecdir}/amanda/application/amzfs-snapshot
%{_libexecdir}/amanda/application/script-email
%{_libexecdir}/amanda/application/script-fail
%verify(not mode) %attr(0750,root,%{amanda_group})%{_libexecdir}/amanda/ambind
%verify(not mode) %attr(0750,root,%{amanda_group})%{_libexecdir}/amanda/application/ambsdtar
%verify(not mode) %attr(0750,root,%{amanda_group})%{_libexecdir}/amanda/application/amgtar
%verify(not mode) %attr(0750,root,%{amanda_group})%{_libexecdir}/amanda/application/amstar
%verify(not mode) %attr(0750,root,%{amanda_group})%{_libexecdir}/amanda/calcsize
%verify(not mode) %attr(0750,root,%{amanda_group})%{_libexecdir}/amanda/killpgrp
%verify(not mode) %attr(0750,root,%{amanda_group})%{_libexecdir}/amanda/rundump
%verify(not mode) %attr(0750,root,%{amanda_group})%{_libexecdir}/amanda/runtar
# include shared libs
%dir %{_libdir}/amanda/
%{_libdir}/amanda/lib*

%check
make %{?_smp_mflags} check

%changelog
* Thu Jul 25 2024 Marcus Meissner <meissner@suse.com>
- amanda-fix-proto.patch: fix build with gcc14
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Feb  7 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Provide user/group symbol for user created during pre.
* Fri Jul 28 2023 pgajdos@suse.com
- version update to 3.5.4
  * Fixed: arg checking for runtar.c (CVE-2023-30577) [bsc#1213701]
- modified patches
  %% amanda-2.6.1p1-avoid-perl-provides.patch (refreshed)
* Mon Jul  3 2023 Danilo Spinella <danilo.spinella@suse.com>
- Fix the user owner of the files in /usr from amanda to root, bsc#1172572
* Tue Mar 21 2023 Danilo Spinella <danilo.spinella@suse.com>
- Update to version 3.5.3:
  * Fixed: removed vulnerable jQuery dependency
  * Fixed: fix suppressed 1st char of error message in
    common-src/bsdtcp-security.c
  * docs: improved README with Markdown
  * docs: updated README file name for docs in Debian builds
  * Fixed: post_inst_functions.sh to create amkey
  * Fixed: added extern keyword for tu_debugging_enabled declaration in
    testutils.h
  * Fixed: https://sogis.eu complaint symmetric encryption key derivation algorithm
  * Fixed: removed perror to fix information leak vulnerability found in the
    calcsize SUID binary. (CVE-2022-37703, bsc#1203390)
  * Fixed: added filter for RSH environment settings in rundump to fix
    privilege escalation vulnerability (CVE-2022-37704, bsc#1208033)
  * Fixed: arg checking for runtar.c (CVE-2022-37705, bsc#1208032)
- Remove upstreamed patches:
  * CVE-2022-37705.patch
  * amanda-3.5.1-GCC10_extern.patch
  * amanda-3.5.2-fix-tests.patch
* Thu Feb 16 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add CVE-2022-37705.patch to fix privilege scalation
  (boo#1208032, gh#zmanda/amanda#194)
* Fri Oct  7 2022 Thorsten Kukuk <kukuk@suse.com>
- %%_docdir/amanda should be mode 755 and not 644
* Thu Aug 25 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 3.5.2:
  * amstatus
    + new --[no]taped argument, useful when running
    'watch amstatus CONF --summary --notaped' if the run have
    many tapes
  * amvault
    + new --uniq, --no-uniq argument
    + Behavior change: The default is --uniq
    + new --delayed argument
    + new --run-delayed argument
- Switch sources from Sourceforge to Github.
- Drop amanda-timestamp.patch: Makefile now handles
  SOURCE_DATE_EPOCH.
- Refresh patches on Perl bindings so that they apply on swig files
  since generated C files are not included in sources anymore:
  * amanda-2.6.1p1-return_val.patch
  * amanda-3.5-no_return_in_nonvoid_fnc.patch
- Add amanda-3.5.2-fix-tests.patch: Fix tests on Tumbleweed
  (gh#zmanda/amanda#167).
- Add build dependencies on swig and rpcgen: Generated files are
  not included in sources anymore.
- Remove redundant %%configure options.
* Mon Jun  8 2020 Kristyna Streitova <kstreitova@suse.com>
- add amanda-3.5.1-GCC10_extern.patch to fix build with GCC10
* Thu Nov 28 2019 Kristyna Streitova <kstreitova@suse.com>
- change %%{_libexecdir}/amanda/application/ owner to root otherwise
  chkstat refuses to set correct permissions there
- add missing BuildRequires
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Fri May 17 2019 Kristýna Streitová <kstreitova@suse.com>
- update the list of suid binaries [bsc#1110797]
  * added: ambind, ambsdtar, amgtar, amstar
  * removed: amcheck, planner, dumper
- update README.SUSE and add a note about setuid binaries and the
  fact that user amanda and members of the group amanda should be
  considered privileged users
* Mon Mar 26 2018 dimstar@opensuse.org
- Own %%{_sysconfdir}/xinetd.d: filesystem won't own this directory
  much longer (boo#1084457).
* Wed Mar 21 2018 crrodriguez@opensuse.org
- Buildrequire curl and libcrypto (enables amazon s3 module)
- amanda-libnsl.patch: libnsl is gone, replaced by tirpc
  fix configure checks.
- Buildrequire libtirpc
* Wed Dec 13 2017 kstreitova@suse.com
- update to 3.5.1
  * do not check all 'r' bit on suid binary
  * fix parsing of configuration override (-o)
  * can unset some setting
  * client code will not fail if shared memory is not available
  * amreport
  * lot of improvement
  * allow '*' for a datestamp wildcard
  * amgetconf
  * print an empty string if a parameter is not set instead of
    'no such parameter'
  * amdump
  * new --no-dump, --no-flush and --no-vault argument
  * amstatus fix
  * lock holding disk to protect multiple parallel access
* Fri Oct 13 2017 kstreitova@suse.com
- update to 3.5
  * see ReleaseNotes for more information
  * refresh
    amanda-2.6.1p1-shellbang.patch
    amanda-2.6.1p1-return_val.patch
    amanda-timestamp.patch
  * remove (applied upstream)
    amanda-automake_add_missing.patch
    amanda-3.3.3-noundefbool.patch
    amanda-2.6.1p1-fix-perl-format.patch
  * remove chg-* scripts from the filelist
  * pack new files
- add amanda-3.5-no_return_in_nonvoid_fnc.patch to fix
  no-return-in-nonvoid-function rpmlint error
- add url for source
- remove SLE11 specific stuff from specfile
- SuSE -> SUSE
  * amanda-SuSE.tar.bz2 is now amanda-SUSE.tar.bz2
  * README.SuSE is now README.SUSE
- tweak description
- run make check
- use %%configure macro
- renumber patches
- create a symlink for amoldrecover manpage
* Thu Mar 23 2017 kstreitova@suse.com
- cleanup with spec-cleaner
* Wed Mar  8 2017 sfalken@opensuse.org
- Added lines to %%files to clear unpackaged files error in
  openSUSE:Factory
* Fri Jan 27 2017 kstreitova@suse.com
- add openssh to BuildRequires to support ssh [bsc#1022028]
* Sat Apr 16 2016 zaitor@opensuse.org
- Replace libsmbclient and libsmbclient-devel for
  pkgconfig(smbclient) BuildRequires: Following samba changes.
* Fri Mar  4 2016 olaf@aepfle.de
- Remove timestamp from binary
  amanda-timestamp.patch
* Thu Nov 27 2014 mpluskal@suse.com
- Fix for boo#907361 -- amanda-2.6.1p1-fix-perl-format.patch
- Clean spec file with spec-cleaner
* Tue Sep 16 2014 darin@darins.net
- wrap %%post permissions routines in conditionals for SLES
* Mon Sep 15 2014 darin@darins.net
- update to 3.3.6
  * ambsdtar
    new application that use BSD tar to do the backup.
  3.3.5 release notes
  * faster 'verify' command.
    fix parsing of config override arguments.
  * amsamba
    Add REGEX-MATCH property.
  * amvault
    Print progress status.
  * ndmp device
    INDIRECT property default to yes.
  3.3.4 release notes
  * amreport
    new --format argument
    new 'json' and 'json_raw' format.
  * amanda.conf
    new REPORT-FORMAT option.
  * amtape
    new 'verify' command.
  * amadmin
    new 'force-level-1' command.
  * ampgsql
    Add VERBOSE property.
  * S3 device
    handle DURABLE_REDUCED_AVAILABILITY for google storage.
  See ChangeLog for a full listing of changes:
    /usr/share/doc/packages/amanda/ChangeLog
- removed amanda-gets.patch, applied upstream
* Mon Jul 21 2014 mls@suse.de
- comment out all 'undef bool' lines, as they break the build
  with modern perl versions
  added patch: amanda-3.3.3-noundefbool.patch
* Fri Apr 26 2013 mmeister@suse.com
- Added automake --add-missing option to fix build with new automake
* Fri Jan 11 2013 vdziewiecki@suse.com
-Update to 3.3.3
  * amdump.X log files use timestamp instead of number, amdump and amdump.1
    are maintained as symlink.
  * chg-disk
    o Use the changerfile for the statefile.
  * s3 device
    o support CASTOR storage
  * amanda.conf
    o New REPORT-USE-MEDIA and REPORT-NEXT-MEDIA.
  * amfetchdump
    o new --extract, --directory, --data-path and --application-property
    arguments. It allow to do the extraction on the server.
  * --exact-match argument to many command, and '=' prefix to expression.
    o It diable use of expression for host, disk, level and datestamp on
    command line argument.
  * All changer scripts.
    o Add LOCK-TIMEOUT property.
  * Many bug fix
-Fixed bnc#784375 - Clarify licensing of amanda. Zmanda changed its
  licensing from GPL-2.0 to GPL-2.0+ and LGPLv2 to LGPLv2+.
* Fri Oct  5 2012 jmatejek@suse.com
- fixed some functions without return values
* Wed Oct  3 2012 vdziewiecki@suse.com
-Update to 3.3.2 (see NEWS)
-Remove queue patch (fixed upstream, see ChangeLog)
-Replaced %%run_permissions with %%set_permissions (bnc#764124)
* Mon Jul 30 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Tue Feb  7 2012 jmatejek@suse.com
- removed custom definition of g_queue_free_full which was
  conflicting with a function newly added to glib2
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Wed Aug 10 2011 jmatejek@novell.com
- explicit permissions for docdir (fixes failure on SLE11)
- %%pre script can now handle a situation where user doesn't exist
* Thu Jun 23 2011 jmatejek@novell.com
- update to version 3.3.0
  * the following changers were dropped:
    chg-chio, chg-chs, chg-iomega, chg-juke, chg-mcutil, chg-mtx,
    chg-null, chg-rait, chg-rth, chg-scsi-chio, chg-scsi
  - see amanda-changers(7) for replacements
  * deprecated configuration keywords:
    label_new_tapes, tapebufs, file-pad, amrecover_do_fsf,
    amrecover_check_label
  * amidxtaped now requires CONFIG parameter, meaning that
    amrecover < 2.4.3 will be unable to recover from new servers
  * need to specify a changer device explicitly
  * default auth is now "bsdtcp"
  * amtape behavior was changed, see amtape manpage for details
  * better cmdline interface for amreport (just "amreport $config")
  * multiple simultaneous writes - can write to all drives in parallel
  * many new features and bugfixes, see NEWS file for details
- -pie and -fPIE are now part of global CFLAGS/LDFLAGS
* Sat Apr 30 2011 coolo@opensuse.org
- amanda-2.6.1p1-avoid-perl-provides.patch:
  patch perl code not to trigger bogus perl provides
* Wed Feb  9 2011 ro@suse.de
- amanda-2.6.1p1-newer_glib.patch:
  at least glib-2.27 brings g_list_free_full and g_slist_free_full
  with own definitions, prefix local variant with my_
* Mon Aug 30 2010 cristian.rodriguez@opensuse.org
- Do not hardcode build date in binaries
* Wed Nov 25 2009 meissner@suse.de
- rediffed patches
* Mon Aug 31 2009 ro@suse.de
- fix archive compression
* Wed Jul 29 2009 mseben@suse.cz
- updated to version 2.6.1p1
  - amplot: better output
  - don't include genversion.h in distribution tarballs.
  - many bugs fixed :S3 device driver,rait device driver
  amstatus, configure, application-api, others small bug
* Fri Jun 12 2009 mseben@suse.cz
- update to version 2.6.1
  - four new programs implementing application-api:
  amgtar, amstar, amsamba, amzfs-sendrecv
  - swithching from the program "GNUTAR" to the application "amgtar"
  - two new scripts implementing script-api : amzfs-snapshot, script-email
  - added new program amarchiver to manipulate file in amanda archive format
  - added new perl modules:
  * Application (perl utility functions for Applications)
  * Archive (Perl access to the  amanda archive library)
  * Constants (perl access to build-time configuration values)
  * MainLoop (Perl interface to the Glib MainLoop)
  * Process (interface to process), used by amcleanup.
  * Script (perl utility functions for Scripts)
  * Tapelist (Manipulate the Amanda tapelist)
  * Xfer (Xfer-api)
- obsolete *-no_chown.patch,*-chg-multi.patch,*-gnulib.patch
- added *-return_val.patch to fix NULL return value
- added *-amxfer_version.patch to fix libamxfer version name
- updated amanda-how-to-collection.pdf
- amanda user has now primary group amanda (created in %%pre phase)
  and supplementary group tape (see also bnc#523006)
* Mon Feb 16 2009 ro@suse.de
- drop lprng in buildreq
* Mon Aug 18 2008 lmichnovic@suse.cz
- fixed missing exclude.gtar file [bnc#412636]
- fixed .amandahosts permission [bnc#412636]
* Wed Jul 16 2008 lmichnovic@suse.cz
- removed unnecessary Requires on glibc-devel ncurses-devel
* Fri Jun 27 2008 schwab@suse.de
- Fix gnulib macros.
* Fri Apr 11 2008 schwab@suse.de
- Remove broken libtool macros.
* Fri Feb  1 2008 lmichnovic@suse.cz
- compiling with option --with-maxtapeblocksize=256 [bnc#353239]
* Fri Nov  9 2007 lmichnovic@suse.cz
- installing only *.txt documentation files
- no need for executable perms for file /usr/lib/amanda/suidlist
* Thu Jul 12 2007 lmichnovic@suse.cz
- added upstream chg-multi.patch
- fixed missing shellbang (shellbang.patch)
* Fri Jun  8 2007 lmichnovic@suse.cz
- update 2.5.2p1
  * Many IPv6 bugs fixed:
  + missing sockaddr_storage
  + missing AI_V4MAPPED and AI_ALL
  + compare of IPv4 and IPv6 v4mapped address.
  + (bsd/bsdudp): server use two sockets,
    one for IPv4 and one for IPv6
  * amflush/autoflush
  * chown/chmod
  * amstatus
  * compilation on some platform
* Thu May 17 2007 lmichnovic@suse.cz
- adjusted *no_chown.patch
* Thu May 17 2007 lmichnovic@suse.cz
- update to version 2.5.2 final
  * some more bug fixes against beta
* Tue Apr 24 2007 lmichnovic@suse.cz
- update to version 2.5.2 beta 1
  * Many bugs fixed and code cleanup
  * krb5 auth is working
  * Works with IPv6 address
  * Amanda configuration file changes
    o amanda.conf changes
    + debugging is enabled in the config file
    see all debug_* config option
    + tapetype 'readblocksize', if maxtapeblocksize is set too
    larger for your hardware
- installing HOWTO-collection.pdf as doc
- excluding static libs
* Tue Feb 13 2007 lmichnovic@suse.cz
- update to version 2.5.1p3
  * Many bugs fixed
  * amrecover improve handling of not ascii filename in index.
  * Works with tar-1.16 and exit status of 1.
  * Can define a LASTSLOT in a chg-disk config file.
  - obsoletes *overflow.patch
* Fri Feb  9 2007 ro@suse.de
- allow build as non-root
* Mon Jan 22 2007 lmichnovic@suse.cz
- added libxslt into BuildRequires
- fixed possible overflow (overflow.patch)
* Mon Jan 22 2007 lmichnovic@suse.cz
- updated to 2.5.1p2
  * Many bugs fixed
  * amoverview is working
  * dumptype starttime is working
  Amanda command changes
  - amtape accept the -o arguments
  - amgetconf --list to list all tapetype, dumptype, holdingdisk
    or interface
  - amgetconf can return a value of a specific tapetype, dumptype,
    holdingdisk or interface
* Thu Oct 19 2006 lmichnovic@suse.cz
- changed version to 2.5.1.1
- compiling with fPIC - fixes failing build on some archs
* Tue Oct  3 2006 pnemec@suse.cz
- updated to 2.5.1p1 which not contain license problem
  affected files #196765
  - many bugfixes see NEWS
- minor cleaning in specfile
* Mon Aug 28 2006 pnemec@suse.cz
- removed examples with license problems
  from source tarball #196765
* Fri Jul  7 2006 pnemec@suse.cz
- updated to 2.5.0p2
  added many new features in 2.5.0 (Auto tape labelling,
  security comunication ...)
  fixed many minors bug (in p1) and major bug (in p2)
- added pdf document with actualized howtos
* Thu Apr  6 2006 pnemec@suse.cz
- some other fix for bug #137128 SIGSEGV in amadmin
* Fri Feb 10 2006 pnemec@suse.cz
- aded *-srv.patch to fix bug #137128
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Aug  1 2005 mjancar@suse.cz
- update to 2.4.5
- add glibc-devel and ncurses-devel to Requires
* Mon Jun 20 2005 ro@suse.de
- added pie patch from FC
- use fPIC for libs needed when building binaries with fpie
* Thu Nov 18 2004 ro@suse.de
- use kerberos-devel-packages
* Tue Aug 10 2004 tcrhak@suse.cz
- update to 2.4.4p3
* Fri Feb 20 2004 tcrhak@suse.cz
- update to version 2.4.4p2
* Wed Oct 29 2003 ro@suse.de
- package according to permissions.secure and add run_permissions
* Thu Sep 18 2003 tcrhak@suse.cz
- added quotes around "grep -E" in an assignment in
  chg-manual; patch manual
- fixed script chg-zd-mtx: parse vars from config correctly,
  fixed output when mtx is not found
* Wed Jul 30 2003 stepan@suse.de
- change samba-client dependency to /usr/bin/smbclient
  to make it operable with samba tng
* Wed Jul 30 2003 aj@suse.de
- Fix chown arguments.
* Mon Jul 28 2003 tcrhak@suse.cz
- fixed script chg-zd-mtx
* Fri Jul 25 2003 tcrhak@suse.cz
- update to version 2.4.4p1
* Thu Jun 12 2003 kukuk@suse.de
- added directory to filelist
* Fri Jun  6 2003 mmj@suse.de
- Package forgotten files
- Remove files from buildroot installed elsewhere
* Mon Mar  3 2003 tcrhak@suse.cz
- added amanda libraries to filelist
* Fri Feb 28 2003 tcrhak@suse.cz
- update to version 2.4.4, that fixes many memory leaks
- added xinetd config files
* Fri Feb 14 2003 tcrhak@suse.cz
- update to version 2.4.3
- applied changes proposed for the tape changer script
  [bug #20086] - patch mtx
* Tue Oct 29 2002 ro@suse.de
- remove (old) libtool macros from acinclude.m4
* Fri Aug 30 2002 tcrhak@suse.cz
- fixed neededforbuild so that smbclient is identified by configure,
  added samba-client to Requires (bug #15818)
* Mon Jul  8 2002 mmj@suse.de
- Using useradd in the package itself.
* Wed Apr  3 2002 tcrhak@suse.cz
- build with new automake/autoconf
* Sat Mar  9 2002 ro@suse.de
- replaced lprold by lprng in neededforbuild
* Thu Nov 22 2001 tcrhak@suse.cz
- Added ps label templates (bugzilla #12270)
- Added README.SuSE
* Mon Nov 12 2001 schwab@suse.de
- Fix for automake 1.5 and autoconf 2.52.
* Mon Aug 20 2001 dan@suse.cz
- update to 2.4.2p2
* Fri May  4 2001 pblaha@suse.cz
- fix permisions 644 for .bashrc  .amandahosts and .profile
- in amanda home /var/lib/amanda/
* Thu Feb 22 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Thu Jan 11 2001 sf@suse.de
- added './' and 'config' to %%{suse_update_config} to make
  it build on IA64
* Fri Jan  5 2001 smid@suse.cz
- file permission changes
- default configuration changes
* Sun Dec  3 2000 smid@suse.cz
- new version 2.4.2
* Tue Nov 21 2000 uli@suse.de
- fixed to build on PPC
* Mon Sep 25 2000 smid@suse.cz
- binaries moved to /usr/sbin
* Mon Sep 18 2000 smid@suse.cz
- Y2K bugfix
* Tue Jun 20 2000 schwab@suse.de
- Add %%suse_update_config.
* Thu May 25 2000 smid@suse.cz
- /usr/doc/packages => %%{_defaultdocdir}
* Fri Apr  7 2000 smid@suse.cz
- url added
* Thu Jan 20 2000 kukuk@suse.de
- /usr/man -> /usr/share/man
- clean up configuration and spec file
* Thu Oct  7 1999 kukuk@suse.de
- Add needed tools to needforbuild
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Jun 25 1999 kukuk@suse.de
- Update to 2.4.1p1 from jurix
- add glibc 2.1 patch
* Sat Dec  5 1998 ro@suse.de
- disabled setresuid/setresgid (while some are still using 2.0)
* Thu Feb  5 1998 florian@suse.de
- first rpm-package of amanda for SuSE
* Thu Jan  2 1997 florian@suse.de
- first S.u.S.E.-version of amanda 2.3.0
- not really supported yet...   :-)
